# NAViz GUI

GUI for NAViz.

## Building

This application can be compiled both for web using [trunk](https://trunkrs.dev/) by calling `trunk build` and for desktop/native using `cargo build`.

## License

This application is licensed nuder the [GNU AGPL](https://www.gnu.org/licenses/agpl-3.0.txt).
It is based on the [eframe_template](https://github.com/emilk/eframe_template/tree/ac47eafb17cef09c4b3cb0ba4f523b68367bdd57),
which is licensed under the [MIT](https://github.com/emilk/eframe_template/blob/ac47eafb17cef09c4b3cb0ba4f523b68367bdd57/LICENSE-MIT)
and [Apache 2.0](https://github.com/emilk/eframe_template/blob/ac47eafb17cef09c4b3cb0ba4f523b68367bdd57/LICENSE-APACHE) license.
